<?php

namespace Proplance\Realestate\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Proplance\Realestate\Interfaces\PropertyRepositoryInterface;

class PropertyPublicController extends BaseController
{
    // use PropertyWorkflow;

    /**
     * Constructor.
     *
     * @param type \Proplance\Property\Interfaces\PropertyRepositoryInterface $property
     *
     * @return type
     */
    public function __construct(PropertyRepositoryInterface $property)
    {
        $this->repository = $property;
        parent::__construct();
    }

    /**
     * Show property's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $properties = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('realestate::property.names'))
            ->view('realestate::public.property.index')
            ->data(compact('properties'))
            ->output();
    }


    /**
     * Show property.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $property = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($property->name . trans('realestate::property.name'))
            ->view('realestate::public.property.show')
            ->data(compact('property'))
            ->output();
    }

}
