<?php

namespace Proplance\Realestate\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Proplance\Realestate\Interfaces\RequirementRepositoryInterface;

class RequirementPublicController extends BaseController
{
    // use RequirementWorkflow;

    /**
     * Constructor.
     *
     * @param type \Proplance\Requirement\Interfaces\RequirementRepositoryInterface $requirement
     *
     * @return type
     */
    public function __construct(RequirementRepositoryInterface $requirement)
    {
        $this->repository = $requirement;
        parent::__construct();
    }

    /**
     * Show requirement's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $requirements = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('realestate::requirement.names'))
            ->view('realestate::public.requirement.index')
            ->data(compact('requirements'))
            ->output();
    }


    /**
     * Show requirement.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $requirement = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($requirement->name . trans('realestate::requirement.name'))
            ->view('realestate::public.requirement.show')
            ->data(compact('requirement'))
            ->output();
    }

}
