<?php

namespace Proplance\Realestate\Policies;

use Litepie\User\Contracts\UserPolicy;
use Proplance\Realestate\Models\Requirement;

class RequirementPolicy
{

    /**
     * Determine if the given user can view the requirement.
     *
     * @param UserPolicy $user
     * @param Requirement $requirement
     *
     * @return bool
     */
    public function view(UserPolicy $user, Requirement $requirement)
    {
        if ($user->canDo('realestate.requirement.view') && $user->isAdmin()) {
            return true;
        }

        return $requirement->user_id == user_id() && $requirement->user_type == user_type();
    }

    /**
     * Determine if the given user can create a requirement.
     *
     * @param UserPolicy $user
     * @param Requirement $requirement
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('realestate.requirement.create');
    }

    /**
     * Determine if the given user can update the given requirement.
     *
     * @param UserPolicy $user
     * @param Requirement $requirement
     *
     * @return bool
     */
    public function update(UserPolicy $user, Requirement $requirement)
    {
        if ($user->canDo('realestate.requirement.edit') && $user->isAdmin()) {
            return true;
        }

        return $requirement->user_id == user_id() && $requirement->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given requirement.
     *
     * @param UserPolicy $user
     * @param Requirement $requirement
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Requirement $requirement)
    {
        return $requirement->user_id == user_id() && $requirement->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given requirement.
     *
     * @param UserPolicy $user
     * @param Requirement $requirement
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Requirement $requirement)
    {
        if ($user->canDo('realestate.requirement.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given requirement.
     *
     * @param UserPolicy $user
     * @param Requirement $requirement
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Requirement $requirement)
    {
        if ($user->canDo('realestate.requirement.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
