<?php

namespace Proplance\Realestate\Providers;

use Illuminate\Support\ServiceProvider;

class RealestateServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'realestate');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'realestate');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerRealestate();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerRealestate()
    {
        $this->app->bind('realestate', function($app) {
            return new Realestate($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Realestate', 'Lavalite\Realestate\Facades\Realestate');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('proplance.realestate', function ($app) {
            return $this->app->make('Proplance\Realestate\Realestate');
        });

        // Bind Property to repository
        $this->app->bind(
            'Proplance\Realestate\Interfaces\PropertyRepositoryInterface',
            \Proplance\Realestate\Repositories\Eloquent\PropertyRepository::class
        );
        // Bind Category to repository
        $this->app->bind(
            'Proplance\Realestate\Interfaces\CategoryRepositoryInterface',
            \Proplance\Realestate\Repositories\Eloquent\CategoryRepository::class
        );
        // Bind Requirement to repository
        $this->app->bind(
            'Proplance\Realestate\Interfaces\RequirementRepositoryInterface',
            \Proplance\Realestate\Repositories\Eloquent\RequirementRepository::class
        );

        $this->app->register(\Proplance\Realestate\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Proplance\Realestate\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and realestate's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'proplance.realestate'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeRealestate::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['proplance.realestate'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('proplance/realestate.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/realestate')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/realestate')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
